==> edgedb-0.3.0.tar.gz: lib/src/codecs/uuid.dart <==
/*!
 * This source file is part of the EdgeDB open source project.
 *
 * Copyright 2019-present MagicStack Inc. and the EdgeDB authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import '../errors/errors.dart';
import '../primitives/buffer.dart';
import 'codecs.dart';

class UUIDCodec extends ScalarCodec {
  UUIDCodec(super.tid);

  @override
  // ignore: overridden_fields
  final returnType = 'String';

  @override
  void encode(WriteBuffer buf, dynamic object) {
    if (object is! String) {
      throw InvalidArgumentError(
          'a String was expected, got "${object.runtimeType}"');
    }
    final uuid = object.replaceAll('-', '');
    if (uuid.length != 32) {
      throw InvalidArgumentError('invalid uuid: $object');
    }

    buf.writeInt32(16);
    buf
      ..writeUint32(int.parse(uuid.substring(0, 8), radix: 16))
      ..writeUint32(int.parse(uuid.substring(8, 16), radix: 16))
      ..writeUint32(int.parse(uuid.substring(16, 24), radix: 16))
      ..writeUint32(int.parse(uuid.substring(24, 32), radix: 16));
  }

  @override
  String decode(ReadBuffer buf) {
    final uuid = buf.readUUID();
    return '${uuid.substring(0, 8)}-${uuid.substring(8, 12)}-'
        '${uuid.substring(12, 16)}-${uuid.substring(16, 20)}-${uuid.substring(20)}';
  }
}

==> edgedb-0.4.0.tar.gz: lib/src/codecs/uuid.dart <==
/*!
 * This source file is part of the EdgeDB open source project.
 *
 * Copyright 2019-present MagicStack Inc. and the EdgeDB authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import '../errors/errors.dart';
import '../primitives/buffer.dart';
import 'codecs.dart';

class UUIDCodec extends ScalarCodec {
  UUIDCodec(super.tid, super.typeName);

  @override
  // ignore: overridden_fields
  final returnType = 'String';

  @override
  void encode(WriteBuffer buf, dynamic object) {
    if (object is! String) {
      throw InvalidArgumentError(
          'a String was expected, got "${object.runtimeType}"');
    }
    final uuid = object.replaceAll('-', '');
    if (uuid.length != 32) {
      throw InvalidArgumentError('invalid uuid: $object');
    }

    buf.writeInt32(16);
    buf
      ..writeUint32(int.parse(uuid.substring(0, 8), radix: 16))
      ..writeUint32(int.parse(uuid.substring(8, 16), radix: 16))
      ..writeUint32(int.parse(uuid.substring(16, 24), radix: 16))
      ..writeUint32(int.parse(uuid.substring(24, 32), radix: 16));
  }

  @override
  String decode(ReadBuffer buf) {
    final uuid = buf.readUUID();
    return '${uuid.substring(0, 8)}-${uuid.substring(8, 12)}-'
        '${uuid.substring(12, 16)}-${uuid.substring(16, 20)}-${uuid.substring(20)}';
  }
}
